@@ -639,7 +639,6 @@ _giraffe_compute_mean_sky(const cpl_image* spectra, const cpl_table* fibers)
 
     cpl_image* sky = NULL;
 
-
     cx_assert(ns == cpl_table_get_nrow(fibers));
 
 
@@ -1231,12 +1230,18 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
     cxint row = 0;
     cxint nmatch = 0;
 
+    cxdouble targ_alpha = 0.;
+    cxdouble targ_delta = 0.;
+    cxdouble ra_hh = 0.;  cxdouble ra_mm = 0.; cxdouble ra_ss = 0.;
+    cxdouble dec_dd = 0.; cxdouble dec_mm = 0.; cxdouble dec_ss = 0.;
     cxdouble ra = 0.;
     cxdouble dec = 0.;
     cxdouble std_ra = 0.;
     cxdouble std_dec = 0.;
     cxdouble min_dist = 0.;
 
+    // Use the TEL.TARG.ALPHA and TEL.TARG.DELTA keywords
+
     const cpl_table* _catalog = NULL;
 
     cpl_table* _flux = NULL;
@@ -1264,13 +1269,48 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
 
     giraffe_error_push();
 
-    ra = cpl_propertylist_get_double(properties, GIALIAS_RADEG);
-    dec = cpl_propertylist_get_double(properties, GIALIAS_DECDEG);
+    if (cpl_propertylist_has(properties, GIALIAS_TARG_ALPHA) ==1) {
+    	targ_alpha = cpl_propertylist_get_double(properties, GIALIAS_TARG_ALPHA);  //5106.500
+    	ra_hh = (int) (targ_alpha/10000);
+    	ra_mm = (int) ((targ_alpha-ra_hh*10000)/100);
+    	ra_ss = targ_alpha -(ra_hh*10000 + ra_mm*100);
+    	// RA:
+    	ra_hh = ra_hh * 15.0;
+    	ra_mm = ra_mm * 15.0 / 60.0;
+		ra_ss = ra_ss * 15.0 / 3600.0;
+		ra = ra_hh + ra_mm + ra_ss;
+		if (ra >= 360.0) {
+			ra = abs(ra  - 360.0);
+		}
+    }
+    else {
+    	ra = cpl_propertylist_get_double(properties, GIALIAS_RADEG); //12.778222
+    }
+
+    if (cpl_propertylist_has(properties, GIALIAS_TARG_DELTA) ==1 ){
+    	targ_delta = cpl_propertylist_get_double(properties, GIALIAS_TARG_DELTA); //-730439.400
+    	dec_dd = (int) (targ_delta/10000);
+    	dec_mm = (int) ((targ_delta-dec_dd*10000)/100);
+    	dec_ss = targ_delta -(dec_dd*10000 + dec_mm*100);
+
+    	// DEC:
+    	if (dec_dd < 0.0) {
+    		dec = dec_dd - (dec_mm/60.0) - (dec_ss/3600.0);
+    	}
+    	else {
+    		dec = dec_dd + (dec_mm/60.0) + (dec_ss/3600.0);
+    	}
+    }
+    else {
+    	dec = cpl_propertylist_get_double(properties, GIALIAS_DECDEG); //-73.07761
+    }
+
 
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
-        return NULL;
+    	return NULL;
     }
 
+
     giraffe_error_pop();
 
 
@@ -1278,106 +1318,105 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
      * Search for matching objects in the flux standards catalog
      */
 
-    cpl_msg_debug(_id, "Searching flux standard by name...");
+    cpl_msg_info(_id, "Searching flux standard by coordinates...");
 
-    if ((cpl_propertylist_has(properties, GIALIAS_TARGET) == TRUE) &&
-        (cpl_table_has_column(_catalog, "OBJECT") == TRUE)) {
+    if ((cpl_table_has_column(_catalog, "RA_DEG") == FALSE) ||
+        (cpl_table_has_column(_catalog, "DEC_DEG") == FALSE)) {
 
-        const cxchar* target = cpl_propertylist_get_string(properties,
-                GIALIAS_TARGET);
+        cpl_error_set(_id, CPL_ERROR_DATA_NOT_FOUND);
+
+        return NULL;
+
+    }
 
 
-        if ((target != NULL) && (target[0] != '\0')) {
+    for (int i = 0; i < cpl_table_get_nrow(_catalog); ++i) {
 
-            register cxint i = 0;
+        cxdouble cat_ra = cpl_table_get_double(_catalog, "RA_DEG",
+                i, NULL);
+        cxdouble cat_dec = cpl_table_get_double(_catalog, "DEC_DEG",
+                i, NULL);
+
+        cxdouble dist = 0.;
 
 
-            for (i = 0; i < cpl_table_get_nrow(_catalog); ++i) {
+        /*
+         * Compute angular separation between the observation and the
+         * positions given in the flux standards catalog.
+         */
 
-                const cxchar* object = cpl_table_get_string(_catalog,
-                        "OBJECT", i);
+        dist = _giraffe_compute_separation(ra, dec, cat_ra, cat_dec);
 
+        if ((i == 0) || (dist < min_dist)) {
 
-                if (strcmp(target, object) == 0) {
-
-                    cxdouble cat_ra = cpl_table_get_double(_catalog,
-                            "RA_DEG", i, NULL);
-                    cxdouble cat_dec = cpl_table_get_double(_catalog,
-                            "DEC_DEG", i, NULL);
-
-
-                    std_ra = cpl_table_get_double(_catalog,
-                            "RA_DEG", i, NULL);
-                    std_dec = cpl_table_get_double(_catalog,
-                            "DEC_DEG", i, NULL);
-
-                    min_dist = _giraffe_compute_separation(ra, dec,
-                            cat_ra, cat_dec);
-
-                    row = i;
-                    ++nmatch;
-
-                }
+            std_ra = cat_ra;
+            std_dec = cat_dec;
+            min_dist = dist;
 
+            if (dist < max_dist) {
+                ++nmatch;
+                row = i;
             }
 
         }
 
     }
 
-    cpl_msg_debug(_id, "%d flux standards found...", nmatch);
+    cpl_msg_info(_id, "%d flux standards found...", nmatch);
 
 
     if (nmatch == 0) {
 
         cxint i = 0;
 
+        cpl_msg_info(_id, "Searching flux standard by name...");
 
-        cpl_msg_debug(_id, "Searching flux standard by coordinates...");
+        if ((cpl_propertylist_has(properties, GIALIAS_TARGET) == TRUE) &&
+            (cpl_table_has_column(_catalog, "OBJECT") == TRUE)) {
 
-        if ((cpl_table_has_column(_catalog, "RA_DEG") == FALSE) ||
-            (cpl_table_has_column(_catalog, "DEC_DEG") == FALSE)) {
-
-            cpl_error_set(_id, CPL_ERROR_DATA_NOT_FOUND);
-
-            return NULL;
-
-        }
+            const cxchar* target = cpl_propertylist_get_string(properties,
+                    GIALIAS_TARGET);
 
 
-        for (i = 0; i < cpl_table_get_nrow(_catalog); ++i) {
+            if ((target != NULL) && (target[0] != '\0')) {
 
-            cxdouble cat_ra = cpl_table_get_double(_catalog, "RA_DEG",
-                    i, NULL);
-            cxdouble cat_dec = cpl_table_get_double(_catalog, "DEC_DEG",
-                    i, NULL);
-
-            cxdouble dist = 0.;
+                register cxint i = 0;
 
 
-            /*
-             * Compute angular separation between the observation and the
-             * positions given in the flux standards catalog.
-             */
+                for (i = 0; i < cpl_table_get_nrow(_catalog); ++i) {
 
-            dist = _giraffe_compute_separation(ra, dec, cat_ra, cat_dec);
+                    const cxchar* object = cpl_table_get_string(_catalog,
+                            "OBJECT", i);
 
-            if ((i == 0) || (dist < min_dist)) {
 
-                std_ra = cat_ra;
-                std_dec = cat_dec;
-                min_dist = dist;
+                    if (strcmp(target, object) == 0) {
+
+                        cxdouble cat_ra = cpl_table_get_double(_catalog,
+                                "RA_DEG", i, NULL);
+                        cxdouble cat_dec = cpl_table_get_double(_catalog,
+                                "DEC_DEG", i, NULL);
+
+
+                        std_ra = cpl_table_get_double(_catalog,
+                                "RA_DEG", i, NULL);
+                        std_dec = cpl_table_get_double(_catalog,
+                                "DEC_DEG", i, NULL);
+
+                        min_dist = _giraffe_compute_separation(ra, dec,
+                                cat_ra, cat_dec);
+
+                        row = i;
+                        ++nmatch;
+
+                    }
 
-                if (dist < max_dist) {
-                    ++nmatch;
-                    row = i;
                 }
 
             }
 
         }
 
-        cpl_msg_debug(_id, "%d flux standards found...", nmatch);
+        cpl_msg_info(_id, "%d flux standards found...", nmatch);
 
     }
 
@@ -1390,9 +1429,9 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
             const cxchar* object = cpl_table_get_string(_catalog,
                     "OBJECT", row);
 
-            cpl_msg_debug(_id, "No flux standard found within %.4f arcsec",
+            cpl_msg_info(_id, "No flux standard found within %.4f arcsec",
                           max_dist);
-            cpl_msg_debug(_id, "The closest object ('%s') at (RA, Dec) = "
+            cpl_msg_info(_id, "The closest object ('%s') at (RA, Dec) = "
                           "(%.4f, %.4f) is %.4f arcsec away", object, std_ra,
                           std_dec, min_dist);
 
@@ -1409,7 +1448,7 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
             const cxchar* object = cpl_table_get_string(_catalog,
                     "OBJECT", row);
 
-            cpl_msg_debug(_id, "Flux standard ('%s') at (RA, Dec) = "
+            cpl_msg_info(_id, "Flux standard ('%s') at (RA, Dec) = "
                           "(%.4f, %.4f) found at a distance of %.4f arcsec",
                           object, std_ra, std_dec, min_dist);
 
@@ -1429,9 +1468,9 @@ giraffe_select_flux_standard(const GiTable* catalog, const GiImage* spectra,
             const cxchar* object = cpl_table_get_string(_catalog,
                     "OBJECT", row);
 
-            cpl_msg_debug(_id, "%d flux standards found within %.4f arcsec",
+            cpl_msg_info(_id, "%d flux standards found within %.4f arcsec",
                           nmatch, max_dist);
-            cpl_msg_debug(_id, "The closest object ('%s') at (RA, Dec) = "
+            cpl_msg_info(_id, "The closest object ('%s') at (RA, Dec) = "
                           "(%.4f, %.4f) is %.4f arcsec away", object, std_ra,
                           std_dec, min_dist);
 
@@ -1808,6 +1847,7 @@ giraffe_fxcalibration_config_create(cpl_parameterlist* parameters)
      */
 
     self->sky_subtraction = FALSE;
+    self->max_dist = 3.0;
 
     /*
      * Lookup the parameters in the given parameter list and set the
@@ -1821,6 +1861,13 @@ giraffe_fxcalibration_config_create(cpl_parameterlist* parameters)
         self->sky_subtraction = cpl_parameter_get_bool(p);
     }
 
+    p = cpl_parameterlist_find(parameters,
+            "giraffe.fxcalibration.max.dist");
+
+    if (p != NULL) {
+        self->max_dist = cpl_parameter_get_double(p);
+    }
+
     return self;
 
 }
@@ -1884,6 +1931,14 @@ giraffe_fxcalibration_config_add(cpl_parameterlist* parameters)
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "flx-skycorr");
     cpl_parameterlist_append(parameters, p);
 
+    p = cpl_parameter_new_value("giraffe.fxcalibration.max.dist",
+                                CPL_TYPE_DOUBLE,
+                                "Standar star search radius ",
+                                "giraffe.fxcalibration",
+                                60.0);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "max-dist");
+    cpl_parameterlist_append(parameters, p);
+
     return;
 
 }
