@@ -1,7 +1,12 @@
+# ========================================================================================================
+#
+# John Pritchard
+#
 ## This script allows a user to run the workflow without PyCosmic installed,
 ## then install PyCosmic and re-run the workflow and then get the PyCosmic
 ## results without having to remove the previous execution
-
+#
+# ========================================================================================================
 # import the needed modules
 import reflex 
 import sys
@@ -18,7 +23,7 @@ try:
 
 except ImportError:
     import_sucess = False
-    print "Error importing one or more of the module PyCosmic"
+    print("Error importing one or more of the module PyCosmic")
 
 if __name__ == '__main__':
   
